/*
       #########    ####     #######                     ####                  
       ###########  ####   ###########                   ####                  
       ####   ##### ####  #####     ##    ######    #### ####   #####          
       ####    #### ####  ####         ########## ########### #########        
       ###########  ####  ####        ####   #### ####   ########   ####       
       #########    ####  ###### #### ####  ##### ####  ##### ###   ####       
       ####         ####    #########  ##########  ########## #########        
*/
//by Jan Ritschard
/************************************************************************************************************
*
*	Projekt:	Projektname
*	Datei:		Dateiname.c
*	Authoren:	Name, Vorname
*
* 	Processor:	PIC18F8722 from MICROCHIP
* 	Compiler:	XC8 v1.35 from MICROCHIP
* 	Linker:		MPLINK
*	Programmer:	PICkit 3 from MICROCHIP
*
*	Hardware:	PICado Alpha 2 (PIC18F8722)
*
************************************************************************************************************
*	
*	Beschreibung der Programmfunktionen:
*
*	Hier sind die Funktionen des Programms zu beschreiben. Dabei ist auf die Verwendung der korrekten
*	Bezeichnungen zu achten. Es ist auf die verwendeten Portnamen Bezug zu nehmen.
*	Darauf achten, dass diese Beschreibung aktuell ist.
*	Es ist auf zusätzlich benötige Dokumente (Hardware-Aufbau, Nachweis der Funktionalität) zu verweisen.
*
************************************************************************************************************
*	
*	Versions:
*
*	V.1.0	xx.xx.2016
*
************************************************************************************************************/

/***	Include and Header files   ******************************************************************************/

	#include <xc.h>                         //by Microchip
    #include <p18f8722.h>					//by Microchip

/***	Configuration PIC   *********************************************************************************/

// PIC18F8722 Configuration Bit Settings
// Use project enums instead of #define for ON and OFF.

// CONFIG1H
#pragma config OSC = INTIO67    // Oscillator Selection bits (Internal oscillator block, port function on RA6 and RA7)
#pragma config FCMEN = OFF      // Fail-Safe Clock Monitor Enable bit (Fail-Safe Clock Monitor disabled)
#pragma config IESO = OFF       // Internal/External Oscillator Switchover bit (Two-Speed Start-up disabled)

// CONFIG2L
#pragma config PWRT = OFF       // Power-up Timer Enable bit (PWRT disabled)
#pragma config BOREN = NOSLP    // Brown-out Reset Enable bits (Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled))
#pragma config BORV = 3         // Brown-out Voltage bits (Minimum setting)

// CONFIG2H
#pragma config WDT = OFF        // Watchdog Timer (WDT disabled (control is placed on the SWDTEN bit))
#pragma config WDTPS = 32768    // Watchdog Timer Postscale Select bits (1:32768)

// CONFIG3L
#pragma config MODE = MC        // Processor Data Memory Mode Select bits (Microcontroller mode)
#pragma config ADDRBW = ADDR20BIT// Address Bus Width Select bits (20-bit Address Bus)
#pragma config DATABW = DATA16BIT// Data Bus Width Select bit (16-bit External Bus mode)
#pragma config WAIT = OFF       // External Bus Data Wait Enable bit (Wait selections are unavailable for table reads and table writes)

// CONFIG3H
#pragma config CCP2MX = PORTC   // CCP2 MUX bit (ECCP2 input/output is multiplexed with RC1)
#pragma config ECCPMX = PORTE   // ECCP MUX bit (ECCP1/3 (P1B/P1C/P3B/P3C) are multiplexed onto RE6, RE5, RE4 and RE3 respectively)
#pragma config LPT1OSC = OFF    // Low-Power Timer1 Oscillator Enable bit (Timer1 configured for higher power operation)
#pragma config MCLRE = ON       // MCLR Pin Enable bit (MCLR pin enabled; RG5 input pin disabled)

// CONFIG4L
#pragma config STVREN = ON      // Stack Full/Underflow Reset Enable bit (Stack full/underflow will cause Reset)
#pragma config LVP = OFF        // Single-Supply ICSP Enable bit (Single-Supply ICSP disabled)
#pragma config BBSIZ = BB2K     // Boot Block Size Select bits (1K word (2 Kbytes) Boot Block size)
#pragma config XINST = OFF      // Extended Instruction Set Enable bit (Instruction set extension and Indexed Addressing mode disabled (Legacy mode))

// CONFIG5L
#pragma config CP0 = OFF        // Code Protection bit Block 0 (Block 0 (000800, 001000 or 002000-003FFFh) not code-protected)
#pragma config CP1 = OFF        // Code Protection bit Block 1 (Block 1 (004000-007FFFh) not code-protected)
#pragma config CP2 = OFF        // Code Protection bit Block 2 (Block 2 (008000-00BFFFh) not code-protected)
#pragma config CP3 = OFF        // Code Protection bit Block 3 (Block 3 (00C000-00FFFFh) not code-protected)
#pragma config CP4 = OFF        // Code Protection bit Block 4 (Block 4 (010000-013FFFh) not code-protected)
#pragma config CP5 = OFF        // Code Protection bit Block 5 (Block 5 (014000-017FFFh) not code-protected)
#pragma config CP6 = OFF        // Code Protection bit Block 6 (Block 6 (01BFFF-018000h) not code-protected)
#pragma config CP7 = OFF        // Code Protection bit Block 7 (Block 7 (01C000-01FFFFh) not code-protected)

// CONFIG5H
#pragma config CPB = OFF        // Boot Block Code Protection bit (Boot Block (000000-0007FFh) not code-protected)
#pragma config CPD = OFF        // Data EEPROM Code Protection bit (Data EEPROM not code-protected)

// CONFIG6L
#pragma config WRT0 = OFF       // Write Protection bit Block 0 (Block 0 (000800, 001000 or 002000-003FFFh) not write-protected)
#pragma config WRT1 = OFF       // Write Protection bit Block 1 (Block 1 (004000-007FFFh) not write-protected)
#pragma config WRT2 = OFF       // Write Protection bit Block 2 (Block 2 (008000-00BFFFh) not write-protected)
#pragma config WRT3 = OFF       // Write Protection bit Block 3 (Block 3 (00C000-00FFFFh) not write-protected)
#pragma config WRT4 = OFF       // Write Protection bit Block 4 (Block 4 (010000-013FFFh) not write-protected)
#pragma config WRT5 = OFF       // Write Protection bit Block 5 (Block 5 (014000-017FFFh) not write-protected)
#pragma config WRT6 = OFF       // Write Protection bit Block 6 (Block 6 (01BFFF-018000h) not write-protected)
#pragma config WRT7 = OFF       // Write Protection bit Block 7 (Block 7 (01C000-01FFFFh) not write-protected)

// CONFIG6H
#pragma config WRTC = OFF       // Configuration Register Write Protection bit (Configuration registers (300000-3000FFh) not write-protected)
#pragma config WRTB = OFF       // Boot Block Write Protection bit (Boot Block (000000-007FFF, 000FFF or 001FFFh) not write-protected)
#pragma config WRTD = OFF       // Data EEPROM Write Protection bit (Data EEPROM not write-protected)

// CONFIG7L
#pragma config EBTR0 = OFF      // Table Read Protection bit Block 0 (Block 0 (000800, 001000 or 002000-003FFFh) not protected from table reads executed in other blocks)
#pragma config EBTR1 = OFF      // Table Read Protection bit Block 1 (Block 1 (004000-007FFFh) not protected from table reads executed in other blocks)
#pragma config EBTR2 = OFF      // Table Read Protection bit Block 2 (Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks)
#pragma config EBTR3 = OFF      // Table Read Protection bit Block 3 (Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks)
#pragma config EBTR4 = OFF      // Table Read Protection bit Block 4 (Block 4 (010000-013FFFh) not protected from table reads executed in other blocks)
#pragma config EBTR5 = OFF      // Table Read Protection bit Block 5 (Block 5 (014000-017FFFh) not protected from table reads executed in other blocks)
#pragma config EBTR6 = OFF      // Table Read Protection bit Block 6 (Block 6 (018000-01BFFFh) not protected from table reads executed in other blocks)
#pragma config EBTR7 = OFF      // Table Read Protection bit Block 7 (Block 7 (01C000-01FFFFh) not protected from table reads executed in other blocks)

// CONFIG7H
#pragma config EBTRB = OFF      // Boot Block Table Read Protection bit (Boot Block (000000-007FFF, 000FFF or 001FFFh) not protected from table reads executed in other blocks)


/***	VARIABLES   ************************************************************************************/

	//Beispiele:
	#define LED             LATEbits.LATE2	//RE2 as LED V6
    #define _XTAL_FREQ      1000000         //Fosc  frequency for _delay() library (1MHz)

/***	PRIVATE PROTOTYPES   ***********************************************************************/

void Init(void);			//Aufruf der Initialisierung vor Ausführung des main()

//************************************************************************************************************
//      MAIN PROGRAM
//************************************************************************************************************

void main(void)
{
	Init();				//Initialisierung

	while(1)			//Endlosschleife
	{
		LED = 1;
        __delay_ms(500);
        LED = 0;
        __delay_ms(500);
	}
}//end main();

//*********************************************************************************************
//      INITIALISIERUNG PIC
//*********************************************************************************************

void Init(void)
{

/***	SET VALUES OF VARIABLES   ***********************************************************/

/***	Set Inputs, Outputs   ***************************************************************/
//*//   All PINs with an * are free usable I/O PINs  //*//
    
    //PORTA A0-A5
	TRISAbits.TRISA0 = 1;		//set RA0 as INPUT		not used*
	TRISAbits.TRISA1 = 1;		//set RA1 as INPUT		not used*
	TRISAbits.TRISA2 = 1;		//set RA2 as INPUT		not used*
	TRISAbits.TRISA3 = 1;		//set RA3 as INPUT		not used*
	TRISAbits.TRISA4 = 1;		//set RA4 as INPUT		not used*
    TRISAbits.TRISA5 = 1;		//set RA5 as INPUT		not connected
    //RA6 see the OSC2/CLKO/RA6 pin.
    //RA7 see the OSC1/CLKI/RA7 pin.


	//PORTB B0-B7
	TRISBbits.TRISB0 = 1;		//set RB0 as INPUT		used as BT-mode
	TRISBbits.TRISB1 = 1;		//set RB1 as INPUT		not connected
	TRISBbits.TRISB2 = 1;		//set RB2 as INPUT		not connected
	TRISBbits.TRISB3 = 1;		//set RB3 as INPUT		not connected
	TRISBbits.TRISB4 = 1;		//set RB4 as INPUT		not used*
	TRISBbits.TRISB5 = 1;		//set RB5 as INPUT		not used*
	TRISBbits.TRISB6 = 1;		//set RB6 as INPUT		used as PGC
	TRISBbits.TRISB7 = 1;		//set RB7 as INPUT		used as PGD

	//PORTC C0-C7
	TRISCbits.TRISC0 = 0;		//set RC0 as OUTPUT		used as LED (Exaple!)
	TRISCbits.TRISC1 = 1;		//set RC1 as INPUT		not used*
	TRISCbits.TRISC2 = 0;		//set RC2 as OUTPUT		used as Open-Collector 2
	TRISCbits.TRISC3 = 1;		//set RC3 as INPUT		not connected
	TRISCbits.TRISC4 = 1;		//set RC4 as INPUT		not used*
	TRISCbits.TRISC5 = 1;		//set RC5 as INPUT		not used*
    TRISCbits.TRISC6 = 0;		//set RC6 as OUTPUT		used as BT-UART TX
	TRISCbits.TRISC7 = 1;		//set RC7 as INPUT		used as BT-UART RX

	//PORTD D0-D7
	TRISDbits.TRISD0 = 1;		//set RD0 as INPUT		not connected
	TRISDbits.TRISD1 = 1;		//set RD1 as INPUT		not connected
	TRISDbits.TRISD2 = 1;		//set RD2 as INPUT		used as Switch S3
	TRISDbits.TRISD3 = 1;		//set RD3 as INPUT 		used as Switch S2
	TRISDbits.TRISD4 = 1;		//set RD4 as INPUT		not used*
	TRISDbits.TRISD5 = 1;		//set RD5 as INPUT		not used*
	TRISDbits.TRISD6 = 1;		//set RD6 as INPUT		not used*
	TRISDbits.TRISD7 = 1;		//set RD7 as INPUT		not used*

	//PORTE E0-E7
	TRISEbits.TRISE0 = 1;		//set RE0 as INPUT		not connected
	TRISEbits.TRISE1 = 1;		//set RE1 as INPUT		not connected
	TRISEbits.TRISE2 = 0;		//set RE2 as OUTPUT		used as LED V6
	TRISEbits.TRISE3 = 0;		//set RE3 as OUTPUT		used as LED V7
	TRISEbits.TRISE4 = 0;		//set RE4 as OUTPUT		used as LED V8
	TRISEbits.TRISE5 = 0;		//set RE5 as OUTPUT		used as Open-Collector 1
	TRISEbits.TRISE6 = 0;		//set RE6 as OUTPUT		used as Open-Collector 2
	TRISEbits.TRISE7 = 1;		//set RE7 as INPUT		not connected
    
    //PORTF F0-F7
	TRISFbits.TRISF0 = 1;		//set RF0 as INPUT		not connected
	TRISFbits.TRISF1 = 1;		//set RF1 as INPUT		not used*
	TRISFbits.TRISF2 = 1;		//set RF2 as INPUT		not used*
	TRISFbits.TRISF3 = 1;		//set RF3 as INPUT 		not used*
	TRISFbits.TRISF4 = 1;		//set RF4 as INPUT		not used*
	TRISFbits.TRISF5 = 1;		//set RF5 as INPUT		not used*
	TRISFbits.TRISF6 = 1;		//set RF6 as INPUT		not used*
	TRISFbits.TRISF7 = 1;		//set RF7 as INPUT		not used*
    
    //PORTG G0-G4
	TRISGbits.TRISG0 = 1;		//set RG0 as INPUT		not connected
	TRISGbits.TRISG1 = 1;		//set RG1 as INPUT		not used*
	TRISGbits.TRISG2 = 1;		//set RG2 as INPUT		not used*
	TRISGbits.TRISG3 = 1;		//set RG3 as INPUT 		not connected
	TRISGbits.TRISG4 = 0;		//set RG4 as OUTPUT		used as Open-Collector 4
	//RG5 used as MCLR
    
   //PORTH H0-H7
	TRISHbits.TRISH0 = 1;		//set RH0 as INPUT		not connected
	TRISHbits.TRISH1 = 1;		//set RH1 as INPUT		not connected
	TRISHbits.TRISH2 = 1;		//set RH2 as INPUT		not connected
	TRISHbits.TRISH3 = 1;		//set RH3 as INPUT 		not connected
	TRISHbits.TRISH4 = 1;		//set RH4 as INPUT		not used*
	TRISHbits.TRISH5 = 1;		//set RH5 as INPUT		not used*
	TRISHbits.TRISH6 = 1;		//set RH6 as INPUT		not used*
	TRISHbits.TRISH7 = 1;		//set RH7 as INPUT		not used*
    
    //PORTJ J0-J7
	TRISJbits.TRISJ0 = 1;		//set RJ0 as INPUT		not connected
	TRISJbits.TRISJ1 = 1;		//set RJ1 as INPUT		not connected
	TRISJbits.TRISJ2 = 1;		//set RJ2 as INPUT		not connected
	TRISJbits.TRISJ3 = 1;		//set RJ3 as INPUT 		not connected
	TRISJbits.TRISJ4 = 1;		//set RJ4 as INPUT		not connected
	TRISJbits.TRISJ5 = 1;		//set RJ5 as INPUT		not connected
	TRISJbits.TRISJ6 = 1;		//set RJ6 as INPUT		not connected
	TRISJbits.TRISJ7 = 1;		//set RJ7 as INPUT		not connected

}//end Initialization();

/***	end of file  *********************************************************************************************/
//by Jan Ritschard